@@ -21,24 +21,25 @@ public:
         uri->retain();
     }
 
-    void sync_query_hv () const;
+    void sync_query_hv (pTHX) const;
 
-    SV* query_hv () const {
-        if (!query_cache || query_cache_rev != uri->query().rev) sync_query_hv();
+    SV* query_hv (pTHX) const {
+        if (!query_cache || query_cache_rev != uri->query().rev) sync_query_hv(aTHX);
         return query_cache;
     }
 
     ~XSURI () {
+        dTHX;
         if (query_cache) SvREFCNT_dec(query_cache);
         uri->release();
     }
 
-    static void register_perl_scheme (const char* scheme, const char* perl_class);
-    static SV*  get_perl_class       (const URI* uri);
+    static void register_perl_scheme (pTHX_ const char* scheme, const char* perl_class);
+    static SV*  get_perl_class       (pTHX_ const URI* uri);
 
-    static void add_query_args (URI* uri, SV** sp, I32 items, bool replace = false);
-    static void add_query_hv   (URI* uri, HV*, bool replace = false);
-    static void add_param      (URI* uri, string key, SV* val, bool replace = false);
+    static void add_query_args (pTHX_ URI* uri, SV** sp, I32 items, bool replace = false);
+    static void add_query_hv   (pTHX_ URI* uri, HV*, bool replace = false);
+    static void add_param      (pTHX_ URI* uri, string key, SV* val, bool replace = false);
 
 private:
     typedef std::map<uint64_t, SV*> UriClassMap;
